package org.orekit.spacecraft;

import org.hipparchus.geometry.euclidean.threed.Vector3D;

/**
 * Radar properties.
 */
public class Radar {
	
   /** 
    * Name 
   */
   private String name;

   /** 
    * Range. 
   */
   private double range;
   
   /** 
    * Aperture angle. 
   */
   private double halfAperture;
   
   /** 
    * Main axis orientation in s/c frame
   */
   private Vector3D orientation;
   
   /** 
    * Main axis vector components 
   */
   private double u1;
   private double u2;
   private double u3;
   
   /** 
    * Set radar name 
   */
   public void setName(String name) {
       this.name = name;
   }
   
   /**
    * Set radar range
    * @param radar range (m)
    */
   public void setRange(double range) {
       this.range = range;
   }
   
   /**
    * Set radar half aperture
    * @param aperture angle (rad)
    */
   public void setHalfAperture(double aperture) {
       this.halfAperture = aperture;
   }
   
   /**
    * Set first component of radar orientation vector in s/c frame
    * @param u1
    */
   public void setU1(double u1) {
	   this.u1 = u1;
   }
   
   /**
    * Set second component of radar orientation vector in s/c frame
    * @param u2
    */
   public void setU2(double u2) {
	   this.u2 = u2;
   }
   
   /**
    * Set third component of radar orientation vector in s/c frame
    * @param u3
    */
   public void setU3(double u3) {
	   this.u3 = u3;
   }
   
   /**
    * Set radar orientation vector in s/c frame
    * @param u1
    * @param u2
    * @param u3
    */
   public void setOrientation(double u1, double u2, double u3) {
	   this.setU1(u1);
	   this.setU1(u2);
	   this.setU1(u3);
	   this.orientation = new Vector3D(u1, u2, u3);
   }
   
   /**
    * Get radar range
    * @return radar range (m)
    */
   public double getRange() {
       return range;
   }
   
   /**
    * Get radar half aperture
    * @return radar half aperture (rad)
    */
   public double getHalfAperture() {
       return halfAperture;
   }
   
   /**
    * Get radar name
    * @return radar name (String)
    */
   public String getName() {
       return name;
   }
   
   /**
    * Get radar orientation in s/c frame
    * @return radar orientation (Vector3D)
    */
   public Vector3D getOrientation() {
       return this.orientation;
   }
   
   /**
    * Get first component of radar orientation
    * @return first component of radar orientation
    */
   public double getU1() {
	   return(this.u1);
   }
   
   /**
    * Get second component of radar orientation
    * @return second component of radar orientation
    */
   public double getU2() {
	   return(this.u2);
   }
   
   /**
    * Get third component of radar orientation
    * @return third component of radar orientation
    */
   public double getU3() {
	   return(this.u3);
   }

}
