package org.orekit.spacecraft;

import org.orekit.attitudes.AttitudeProvider;
import org.orekit.propagation.analytical.tle.TLE;

public class SpaceBorneRadar {
	
	/**
	 * Radar object moving with satellite
	 */
	Radar radar;
	
	/**
	 * Template initial TLE 
	 */
	TLE templateTLE;
	
	/**
	 * Attitude provider
	 */
	AttitudeProvider attitudeProvider;
	
	/**
	 * Get radar object
	 * @return radar object (Radar)
	 */
	public Radar getRadar() {
		return radar;
	}
	
	/**
	 * Basic constructor
	 * @param radar onboard radar
	 * @param templateTle template TLE representing initial orbit
	 */
	public SpaceBorneRadar(Radar radar, TLE templateTle) {
		this.radar = radar;
		this.templateTLE = templateTle;
	}
	
	/**
	 * Basic constructor
	 * @param radar onboard radar
	 * @param templateTle template TLE representing initial orbit
	 * @param attitude s/c attitude
	 */
	public SpaceBorneRadar(Radar radar, 
			TLE templateTle, AttitudeProvider attitudeProvider) {
		this(radar, templateTle);
		this.attitudeProvider = attitudeProvider;
	}
	
	/**
	 * Get TLE
	 * @return template TLE
	 */
	public TLE getTLE() {
		return this.templateTLE;
	}
	
	/**
	 * Get attitude provider
	 * @return attitude provider
	 */
	public AttitudeProvider getAttitudeProvider() {
		return this.attitudeProvider;
	}

}
